---
page_type: sample
languages:
- csharp
- cpp
- cppwinrt
products:
- windows
- windows-uwp
urlFragment: DisablingScreenCapture
extendedZipContent:
- path: SharedContent
  target: SharedContent
- path: LICENSE
  target: LICENSE
description: "Shows how to disable screen capture."
---

<!---
  category: IdentitySecurityAndEncryption
  samplefwlink: http://go.microsoft.com/fwlink/p/?LinkId=624047
--->

# Disabling screen capture sample

Shows how to disable screen capture by setting the
[IsScreenCaptureEnabled](http://msdn.microsoft.com/library/windows/apps/dn281123)
property of the
[ApplicationView](http://msdn.microsoft.com/library/windows/apps/hh701658)
object,
and by using methods of the
[AppCapture](https://docs.microsoft.com/uwp/api/Windows.Media.Capture.AppCapture)
class.

> **Note:** This sample is part of a large collection of UWP feature samples. 
> You can download this sample as a standalone ZIP file
> [from docs.microsoft.com](https://docs.microsoft.com/samples/microsoft/windows-universal-samples/disablingscreencapture/),
> or you can download the entire collection as a single
> [ZIP file](https://github.com/Microsoft/Windows-universal-samples/archive/master.zip), but be 
> sure to unzip everything to access shared dependencies. For more info on working with the ZIP file, 
> the samples collection, and GitHub, see [Get the UWP samples from GitHub](https://aka.ms/ovu2uq). 
> For more samples, see the [Samples portal](https://aka.ms/winsamples) on the Windows Dev Center. 

The sample consists of the following scenarios:

- Allow screen capture by taking no special action. Screen capture is allowed by default.
- Blocking screen capture for a specific page
  by setting [IsScreenCaptureEnabled](http://msdn.microsoft.com/library/windows/apps/dn281123)
  to **false** when the user navigates to the page, then setting it back to **true** when the user navigates away.
- Allowing and blocking system-initiated app capture such as Xbox Game Bar.

**Note** The Windows universal samples require Visual Studio to build and Windows 10 to execute.
 
To obtain information about Windows 10 development, go to the [Windows Dev Center](http://go.microsoft.com/fwlink/?LinkID=532421)

To obtain information about Microsoft Visual Studio and the tools for developing Windows apps, go to [Visual Studio](http://go.microsoft.com/fwlink/?LinkID=532422)

## Related topics

### Reference

[ApplicationView class](https://msdn.microsoft.com/library/windows/apps/windows.ui.viewmanagement.applicationview.aspx)  
[Capture game audio, video, screenshots, and metadata](https://docs.microsoft.com/windows/uwp/gaming/capture-game-audio-video-screenshots-and-metadata)  

### Related samples

* [DisablingScreenCapture sample](/archived/DisablingScreenCapture/) for C++/CX and JavaScript (archived)

## System requirements

* Windows 10

## Build the sample

1. If you download the samples ZIP, be sure to unzip the entire archive, not just the folder with the sample you want to build. 
2. Start Microsoft Visual Studio and select **File** \> **Open** \> **Project/Solution**.
3. Starting in the folder where you unzipped the samples, go to the Samples subfolder, then the subfolder for this specific sample, then the subfolder for your preferred language (C++, C#, or JavaScript). Double-click the Visual Studio Solution (.sln) file.
4. Press Ctrl+Shift+B, or select **Build** \> **Build Solution**.

## Run the sample

The next steps depend on whether you just want to deploy the sample or you want to both deploy and run it.

### Deploying the sample

- Select Build > Deploy Solution. 

### Deploying and running the sample

- To debug the sample and then run it, press F5 or select Debug >  Start Debugging. To run the sample without debugging, press Ctrl+F5 or select Debug > Start Without Debugging. 
