---
page_type: sample
languages:
- csharp
- cpp
- cppcx
products:
- windows
- windows-uwp
urlFragment: RadialController
extendedZipContent:
- path: SharedContent
  target: SharedContent
- path: LICENSE
  target: LICENSE
description: "Creates custom menu items for a Surface Dial device, controls the haptic feedback, and configures the default system items."
---

<!---
  category: DevicesAndSensors
  samplefwlink: http://go.microsoft.com/fwlink/p/?LinkId=832873
-->

# Radial Controller sample

Shows how to use the RadialController class
to create custom menu items for a Surface Dial device,
control the haptic feedback, and configure the default system items.

> **Note:** This sample is part of a large collection of UWP feature samples. 
> You can download this sample as a standalone ZIP file
> [from docs.microsoft.com](https://docs.microsoft.com/samples/microsoft/windows-universal-samples/radialcontroller/),
> or you can download the entire collection as a single
> [ZIP file](https://github.com/Microsoft/Windows-universal-samples/archive/master.zip), but be 
> sure to unzip everything to access shared dependencies. For more info on working with the ZIP file, 
> the samples collection, and GitHub, see [Get the UWP samples from GitHub](https://aka.ms/ovu2uq). 
> For more samples, see the [Samples portal](https://aka.ms/winsamples) on the Windows Dev Center. 

Specifically, this sample shows how to:

- **Add, remove, and select custom items:** This sample demonstrates how to add, remove, and select custom items dynamically using system-provided icons,
  app-provided bitmaps, glyphs from a system-provided font, or glyphs from an app-provided font.
- **Control haptic feedback:** This sample demonstrates how to enable and disable the haptic feedback for custom items.
- **Configure default system items:** This sample demonstrates how to add, remove, and select the default system items.
- **Suppress the menu:** Normally, the system displays a menu when the user presses the Surface Dial.
  The app can suppress the menu and direct input to a specific controller.

**Note** The Windows universal samples require Visual Studio to build and Windows 10 to execute.

To obtain information about Windows 10 development, go to the [Windows Dev Center](http://go.microsoft.com/fwlink/?LinkID=532421)

To obtain information about Microsoft Visual Studio and the tools for developing Windows apps, go to [Visual Studio](http://go.microsoft.com/fwlink/?LinkID=532422)

## Related topics

### Developer and UX guidance

[Surface Dial interactions](https://msdn.microsoft.com/windows/uwp/input-and-devices/windows-wheel-interactions)

### Reference

[RadialController](https://msdn.microsoft.com/library/windows/apps/windows.ui.input.radialcontroller.aspx)  
[RadialControllerMenu](https://msdn.microsoft.com/library/windows/apps/windows.ui.input.radialcontrollermenu.aspx)  
[RadialControllerMenuItem](https://msdn.microsoft.com/library/windows/apps/windows.ui.input.radialcontrollermenuitem.aspx)  
[RadialControllerConfiguration](https://msdn.microsoft.com/library/windows/apps/windows.ui.input.radialcontrollerconfiguration.aspx)  

### Other samples

* [RadialController for C++ desktop apps](https://github.com/Microsoft/Windows-classic-samples/tree/master/Samples/RadialController/cpp)
* [RadialController for WinForms desktop apps](https://github.com/Microsoft/Windows-classic-samples/tree/master/Samples/RadialController/cs/winforms)

## System requirements

**Client:** Windows 10

## Build the sample

1. If you download the samples ZIP, be sure to unzip the entire archive, not just the folder with the sample you want to build. 
2. Start Microsoft Visual Studio and select **File** \> **Open** \> **Project/Solution**.
3. Starting in the folder where you unzipped the samples, go to the Samples subfolder, then the subfolder for this specific sample, then the subfolder for the language. Double-click the Visual Studio Solution (.sln) file.
4. Press Ctrl+Shift+B, or select **Build** \> **Build Solution**.

## Run the sample

The next steps depend on whether you just want to deploy the sample or you want to both deploy and run it.

### Deploying the sample

- Select Build > Deploy Solution. 

### Deploying and running the sample

- To debug the sample and then run it, press F5 or select Debug >  Start Debugging. To run the sample without debugging, press Ctrl+F5 or selectDebug > Start Without Debugging. 
